package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.TmstruckLeaveFactoryResultMapper;
import com.steerinfo.dil.mapper.UtilsMapper;
import com.steerinfo.dil.model.TmstruckLeaveFactoryResult;
import com.steerinfo.dil.service.ITmstruckLeaveFactoryResultService;
import com.steerinfo.dil.util.DataChange;
import com.steerinfo.route.service.impl.RouteServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.util.*;

/**
 * TmstruckLeaveFactoryResult服务实现：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-09-11 10:32
 * 类描述
 * 修订历史：
 * 日期：2021-09-11
 * 作者：generator
 * 参考：
 * 描述：TmstruckLeaveFactoryResult服务实现
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@Service(value = "tmstruckLeaveFactoryResultService")
public class TmstruckLeaveFactoryResultServiceImpl implements ITmstruckLeaveFactoryResultService {

    @Autowired
    private ITmstruckLeaveFactoryResultService tmstruckLeaveFactoryResultService;
    @Autowired
    private RouteServiceImpl routeService;
    @Autowired
    private TmstruckLeaveFactoryResultMapper tmstruckLeaveFactoryResultMapper;



    @Autowired
    private UtilsServiceImpl utilsService;

    @Autowired
    private UtilsMapper utilsMapper;



    @Autowired
    OffSiteTransportationServiceImpl offSiteTransportationService;


    /**
     * 查看运输线路是否为出厂
     * @param orderNumber
     * @return
     */
    @Override
    public Integer selectTransportRoute(String orderNumber) {
        return tmstruckLeaveFactoryResultMapper.selectTransportRoute(orderNumber);
    }


    /**
     * 派单后新增出厂实绩
     * 总实绩ID、线路终点
     * @param map
     * @return
     */
    @Override
    public int addLeaveFactory(Map<String, Object> map) {
        TmstruckLeaveFactoryResult tmstruckLeaveFactoryResult = new TmstruckLeaveFactoryResult();
        //添加主键
        tmstruckLeaveFactoryResult.setId(tmstruckLeaveFactoryResultMapper.selectMaxId());
        //添加总实绩ID
        BigDecimal resultTotalId = DataChange.dataToBigDecimal(map.get("resultTotalId"));
        tmstruckLeaveFactoryResult.setResultTotalId(resultTotalId);
        List<Integer> gatepostIdList = utilsMapper.getLineSegmentGateCalcId(map);
        gatepostIdList.remove(null);
        //随机取门岗值
        Integer gatepostId = utilsService.randomGetValue(gatepostIdList);
        //获取门岗ID
        tmstruckLeaveFactoryResult.setGatepostId(new BigDecimal(gatepostId));
        //添加路段顺序号
        tmstruckLeaveFactoryResult.setSegmentSqe(DataChange.dataToBigDecimal(map.get("segmentSqe")));
        //添加门岗ID 出厂门岗为线路的终点
        return tmstruckLeaveFactoryResultMapper.insertSelective(tmstruckLeaveFactoryResult);
    }

    @Override
    public Map<String, Object> getTruckFactoryResult(String nu) {
        return tmstruckLeaveFactoryResultMapper.getTruckFactoryResult(nu);
    }

    /**
     * APP查询出厂信息
     * @param orderNumber
     * @return
     */
    @Override
    public List<Map<String, Object>> getLeaveFactoryList(String orderNumber) {
        return tmstruckLeaveFactoryResultMapper.getLeaveFactoryList(orderNumber);
    }








    /**
     * 内转订单类型
     * @Author TXF
     * @Date 2022/3/18 18:03
     * @param map
     * @param mesMap
     * @param capacityNumber
     * @return
     **/
    public int orderType11Use(Map<String, Object> map, Map<String, Object> mesMap, String capacityNumber){
        //内转订单类型 没有生成实绩 直接新增
        int sqe = DataChange.dataToBigDecimal(mesMap.get("Sqe")).intValue();
        sqe = sqe + 1;
        map.put("resultId",tmstruckLeaveFactoryResultMapper.selectMaxId());//出厂实绩ID
        map.put("Sqe",sqe);//查询路段顺序号+1
        map.put(("totalId"),mesMap.get("totalId"));
        tmstruckLeaveFactoryResultMapper.insertSelective(generateLeaveFactory(map));
        //更新路段顺序号
        mesMap.put("orderLineSequence",sqe);
        utilsService.updateOrderLineSqeByOrderNumber(mesMap);
        utilsService.pushMesToWebsocket(capacityNumber, "出厂");
        return 1;
    }


    //内转订单类型新增出厂实绩
    private TmstruckLeaveFactoryResult generateLeaveFactory(Map<String, Object> map) {
        TmstruckLeaveFactoryResult tmstruckLeaveFactoryResult = new TmstruckLeaveFactoryResult();
        //获取出厂实绩ID
        tmstruckLeaveFactoryResult.setResultId(DataChange.dataToBigDecimal(map.get("resultId")));
        //添加门岗
        tmstruckLeaveFactoryResult.setGatepostId(DataChange.dataToBigDecimal(map.get("gatepostId")));
        //添加路段顺序号
        tmstruckLeaveFactoryResult.setSegmentSqe(DataChange.dataToBigDecimal(map.get("Sqe")));
        //添加出厂时间
        tmstruckLeaveFactoryResult.setResultOutGateTime(new Date());
        tmstruckLeaveFactoryResult.setInsertTime(new Date());
        tmstruckLeaveFactoryResult.setResultOutMode("手动抬杆");
        tmstruckLeaveFactoryResult.setInsertUsername("admin");
        if(map.get("Sqe") !=null){
            tmstruckLeaveFactoryResult.setSegmentSqe(DataChange.dataToBigDecimal(map.get("Sqe")));
        }
        if(map.get("totalId") !=null){
            tmstruckLeaveFactoryResult.setResultTotalId(DataChange.dataToBigDecimal(map.get("totalId")));
        }
        return tmstruckLeaveFactoryResult;
    }


    /**
     * 通过总实绩Id修改出厂实绩出厂门岗
     * @param resultTotalId
     * @param gatepostId
     * @return
     */
    public int updateLeaveFactoryGatepostId(Integer resultTotalId, Integer gatepostId){
        TmstruckLeaveFactoryResult tmstruckLeaveFactoryResult = new TmstruckLeaveFactoryResult();
        //通过总实绩ID查询出产实绩
        BigDecimal resultId = tmstruckLeaveFactoryResultMapper.getResultIdByTotalId(resultTotalId);
        tmstruckLeaveFactoryResult.setResultId(resultId);
        tmstruckLeaveFactoryResult.setGatepostId(new BigDecimal(gatepostId));
        return tmstruckLeaveFactoryResultMapper.updateByPrimaryKeySelective(tmstruckLeaveFactoryResult);
    }

    /**
     * 查询零星物资出厂列表
     * @param mapValue
     * @return
     */
    @Override
    public List<Map<String, Object>> getSporadicLeaveFactory(Map<String, Object> mapValue) {
        return tmstruckLeaveFactoryResultMapper.getSporadicLeaveFactory(mapValue);
    }


}
